@@ -5,46 +5,46 @@
 #'
 #' @param object Object containing MCMC output. See DETAILS below.
 #' @param params Character string (or vector of character strings) denoting parameters of interest.
-#' Partial names may be used to return all parameters containing that set of characters.
 #'
 #' Default \code{'all'} returns chains for all parameters.
 #'
-#' @param excl Character string (or vector of character strings) denoting parameters to exclude.
-#' Partial names may be used to exclude all parameters containing that set of characters. Used in
-#' conjunction with \code{params} argument to select parameters of interest.
+#' @param excl Character string (or vector of character strings) denoting parameters to exclude. Used in conjunction with \code{params} argument to select parameters of interest.
 #'
-#' @param iter Number of iterations to plot for trace and density plots. The default value is 2000,
-#'  meaning the last 2000 iterations of the chain will be plotted.
+#' @param ISB Ignore Square Brackets (ISB). Logical specifying whether square brackets should be ignored in the \code{params} and \code{excl} arguments. If \code{FALSE}, square brackets are ignored - input from \code{params} and \code{excl} are otherwise matched exactly. If \code{TRUE}, square brackets are not ignored - input from \code{params} and \code{excl} are matched using grep, allowing partial names to be used when specifying parameters of interest.
+#'
+#' @param iter Number of iterations to plot for trace and density plots. The default value is 5000, meaning the last 5000 iterations of the chain will be plotted.
 #'
 #' @param pdf Logical - if \code{pdf = TRUE} plots will be exported to a pdf.
-#' @param filename Name of pdf file to be printed.
+#' @param filename Name of pdf file to be printed. Default is 'MCMCtrace'.
 #' @param wd Working directory for pdf output. Default is current directory.
 #' @param type Type of plot to be output. \code{'both'} outputs both trace and density plots, \code{'trace'}
 #' outputs only trace plots, and \code{'density'} outputs only density plots.
-#' @param ind Logical - if \code{ind = TRUE}, different lines will be plotted for each chain. If
-#' \code{ind= FALSE}, one line will be plotted for all chains.
+#' @param ind Logical - if \code{ind = TRUE}, separate density lines will be plotted for each chain. If
+#' \code{ind= FALSE}, one density line will be plotted for all chains.
 #' @section Details:
 #' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), an \code{mcmc.list} object
 #' (\code{coda} package), or an \code{R2jags} model object (\code{R2jags} package). The function automatically
 #' detects the object type and proceeds accordingly.
 #'
+#'
 #' @examples
 #' #Load data
 #' data(MCMC_data)
 #'
-#' #Traceplot for all 'beta' parameters
+#' #Traceplots for all 'beta' parameters
 #' MCMCtrace(MCMC_data, params='beta')
 #'
-#' #Print traceplot output to pdf
-#' MCMCtrace(MCMC_data, pdf= TRUE, filename = 'PDF_file.pdf')
+#' #Traceplots (individual density lines for each chain) for just 'beta[1]'
+#' MCMCtrace(MCMC_data, params = 'beta[1]', ISB = FALSE, filename = 'PDF_file.pdf', ind = TRUE)
 #'
 #' @export
 
 MCMCtrace <- function(object,
                     params = 'all',
                     excl = NULL,
-                    iter = 2000,
-                    pdf = FALSE,
+                    ISB = TRUE,
+                    iter = 5000,
+                    pdf = TRUE,
                     filename,
                     wd = getwd(),
                     type = 'both',
@@ -61,7 +61,7 @@ MCMCtrace <- function(object,
   {
     temp <- object
   }
-  if(coda::is.mcmc.list(object) == FALSE & typeof(object) == 'list')
+  if(class(object) == 'rjags')
   {
     #modified coda::as.mcmc (removing ordering of param names)
     x <- object$BUGSoutput
@@ -70,7 +70,8 @@ MCMCtrace <- function(object,
     strt <- x$n.burnin + 1
     end <- x$n.iter
     ord <- dimnames(x$sims.array)[[3]]
-    for (i in 1:x$n.chains) {
+    for (i in 1:x$n.chains)
+    {
       tmp1 <- x$sims.array[, i, ord]
       mclis[[i]] <- coda::mcmc(tmp1, start = strt, end = end, thin = x$n.thin)
     }
@@ -80,8 +81,21 @@ MCMCtrace <- function(object,
   {
     stop('Invalid input type. Object must be of type stanfit, mcmc.list, or R2jags.')
   }
+  if(coda::is.mcmc.list(object) == FALSE & typeof(object) == 'list' & class(object[[1]]) == 'mcarray')
+  {
+    stop('Invalid object type. jags.samples objects not currently supported. Input must be stanfit object, mcmc.list object, rjags object, or matrix with MCMC chains.')
+  }
 
-  names <- colnames(temp[[1]])
+  #NAME SORTING BLOCK
+  if(ISB == TRUE)
+  {
+    names <- vapply(strsplit(colnames(temp[[1]]),
+                             split = "[", fixed = TRUE), `[`, 1, FUN.VALUE=character(1))
+    a_names <- colnames(temp[[1]])
+  }else{
+    names <- colnames(temp[[1]])
+    a_names <- names
+  }
   n_chains <- length(temp)
   if (nrow(temp[[1]]) > iter)
   {
@@ -90,106 +104,128 @@ MCMCtrace <- function(object,
     it <- 1 : nrow(temp[[1]])
   }
 
+  #INDEX BLOCK
+  #exclusions
   if(!is.null(excl))
   {
-    to.rm1 <- c()
+    rm_ind <- c()
     for (i in 1:length(excl))
     {
-      to.rm1 <- c(to.rm1, grep(excl[i], names, fixed = TRUE))
+      if(ISB == TRUE)
+      {
+        n_excl <- vapply(strsplit(excl,
+                                  split = "[", fixed = TRUE), `[`, 1, FUN.VALUE=character(1))
+        rm_ind <- c(rm_ind, which(names %in% n_excl[i]))
+      }else{
+        n_excl <- excl
+        rm_ind <- c(rm_ind, grep(n_excl[i], names, fixed = TRUE))
+      }
     }
-    dups <- -which(duplicated(to.rm1))
+    if(length(rm_ind) < 1)
+    {
+      stop(paste0('"', excl, '"', ' not found in MCMC ouput.'))
+    }
+    dups <- which(duplicated(rm_ind))
     if(length(dups) > 0)
     {
-      to.rm2 <- to.rm1[-dups]
+      rm_ind2 <- rm_ind[-dups]
     }else{
-      to.rm2 <- to.rm1
+      rm_ind2 <- rm_ind
     }
   }
 
-
+  #selections
   if (length(params) == 1)
   {
     if (params == 'all')
     {
       if(is.null(excl))
       {
-        g_filt <- 1:length(names)
+        f_ind <- 1:length(names)
       }else{
-        g_filt <- (1:length(names))[-to.rm2]
+        f_ind <- (1:length(names))[-rm_ind2]
       }
     }else
     {
-      get.cols <- grep(paste(params), names, fixed=TRUE)
-      if (length(get.cols) < 1)
+      if(ISB == TRUE)
+      {
+        get_ind <- which(names %in% params)
+      }else{
+        get_ind <- grep(paste(params), names, fixed = TRUE)
+      }
+
+      if (length(get_ind) < 1)
       {
         stop(paste0('"', params, '"', ' not found in MCMC ouput.'))
       }
-
       if(!is.null(excl))
       {
-        if(identical(get.cols, to.rm2))
+        if(identical(get_ind, rm_ind2))
         {
           stop('No parameters selected.')
         }
-
-        matched <- which(get.cols == to.rm2)
+        matched <- stats::na.omit(match(rm_ind2, get_ind))
         if (length(matched) > 0)
         {
-          g_filt <- get.cols[-matched]
+          f_ind <- get_ind[-matched]
         }else {
-          g_filt <- get.cols
+          f_ind <- get_ind
         }
-
-      }else{
-        g_filt <- get.cols
+      }else {
+        f_ind <- get_ind
       }
     }
-  }else
-  {
+  }else {
     grouped <- c()
     for (i in 1:length(params))
     {
-      get.cols <- grep(paste(params[i]), names, fixed=TRUE)
-      grouped <- c(grouped, get.cols)
-    }
+      if(ISB == TRUE)
+      {
+        get_ind <- which(names %in% params[i])
+      }else{
+        get_ind <- grep(paste(params[i]), names, fixed=TRUE)
+      }
 
+      if (length(get_ind) < 1)
+      {
+        stop(paste0('"', params[i], '"', ' not found in MCMC ouput.'))
+      }
+      grouped <- c(grouped, get_ind)
+    }
     if(!is.null(excl))
     {
-      if(identical(grouped, to.rm2))
+      if(identical(grouped, rm_ind2))
       {
         stop('No parameters selected.')
       }
-
-      matched <- stats::na.omit(match(to.rm2, grouped))
+      matched <- stats::na.omit(match(rm_ind2, grouped))
       if (length(matched) > 0)
       {
-        cols <- grouped[-matched]
+        t_ind <- grouped[-matched]
       } else{
-        cols <- grouped
+        t_ind <- grouped
       }
-
-      to.rm <- which(duplicated(cols))
+      to.rm <- which(duplicated(t_ind))
       if(length(to.rm) > 0)
       {
-        g_filt <- cols[-to.rm]
+        f_ind <- t_ind[-to.rm]
       }else
       {
-        g_filt <- cols
+        f_ind <- t_ind
       }
     } else{
-
       to.rm <- which(duplicated(grouped))
       if(length(to.rm) > 0)
       {
-        g_filt <- grouped[-to.rm]
+        f_ind <- grouped[-to.rm]
       }else
       {
-        g_filt <- grouped
+        f_ind <- grouped
       }
     }
   }
 
-
+  #OUTPUT BLOCK
   if(pdf == TRUE)
   {
     setwd(wd)
@@ -208,6 +244,8 @@ MCMCtrace <- function(object,
   }
 
 
+  #PLOT BLOCK
+  A_VAL <- 0.5 #alpha value
   graphics::layout(matrix(c(1, 2, 3, 4, 5, 6), 3, 2, byrow = TRUE))
   graphics::par(mar = c(4.1,4.1,2.1,1.1)) # bottom, left, top, right
   graphics::par(mgp = c(2.5,1,0)) #axis text distance
@@ -221,13 +259,13 @@ MCMCtrace <- function(object,
 
   if (type == 'both')
   {
-    for (j in 1: length(g_filt))
+    for (j in 1: length(f_ind))
     {
       #trace
-      tmlt <- do.call('cbind', temp[it, g_filt[j]])
-      graphics::matplot(it, tmlt, lwd = 1, lty= 1, type='l', main = paste0('Trace - ', names[g_filt[j]]),
+      tmlt <- do.call('cbind', temp[it, f_ind[j]])
+      graphics::matplot(it, tmlt, lwd = 1, lty= 1, type='l', main = paste0('Trace - ', a_names[f_ind[j]]),
               col= grDevices::rgb(red= gg_cols[1,], green= gg_cols[2,],
-                       blue= gg_cols[3,], alpha = 0.5),
+                       blue= gg_cols[3,], alpha = A_VAL),
               xlab= 'Iteration', ylab= 'Value')
       if (ind == TRUE & n_chains > 1)
       {
@@ -240,7 +278,7 @@ MCMCtrace <- function(object,
         ylim <- c(0, max(max_den))
 
         graphics::plot(dens[[1]], xlab = 'Parameter estimate', ylim = ylim,
-             lty = 1, lwd = 1, main = paste0('Density - ', names[g_filt[j]]),
+             lty = 1, lwd = 1, main = paste0('Density - ', a_names[f_ind[j]]),
              col = grDevices::rgb(red= gg_cols[1,1], green= gg_cols[2,1], blue= gg_cols[3,1]))
 
         for (l in 2:NCOL(tmlt))
@@ -252,30 +290,30 @@ MCMCtrace <- function(object,
       }else{
         #density plot
         graphics::plot(stats::density(rbind(tmlt)), xlab = 'Parameter estimate',
-             lty = 1, lwd = 1, main = paste0('Density - ', names[g_filt[j]]))
+             lty = 1, lwd = 1, main = paste0('Density - ', a_names[f_ind[j]]))
       }
     }
   }
 
   if (type == 'trace')
   {
-    for (j in 1: length(g_filt))
+    for (j in 1: length(f_ind))
     {
       #chains
-      tmlt <- do.call('cbind', temp[it,g_filt[j]])
-      graphics::matplot(it, tmlt, lwd = 1, lty= 1, type='l', main = paste0('Trace - ', names[g_filt[j]]),
+      tmlt <- do.call('cbind', temp[it,f_ind[j]])
+      graphics::matplot(it, tmlt, lwd = 1, lty= 1, type='l', main = paste0('Trace - ', a_names[f_ind[j]]),
               col= grDevices::rgb(red= gg_cols[1,], green= gg_cols[2,],
-                       blue= gg_cols[3,], alpha = 0.5),
+                       blue= gg_cols[3,], alpha = A_VAL),
               xlab= 'Iteration', ylab= 'Value')
     }
   }
 
   if (type == 'density')
   {
-    for (j in 1: length(g_filt))
+    for (j in 1: length(f_ind))
     {
       #trace
-      tmlt <- do.call('cbind', temp[it,g_filt[j]])
+      tmlt <- do.call('cbind', temp[it,f_ind[j]])
 
       if (ind == TRUE & n_chains > 1)
       {
@@ -288,7 +326,7 @@ MCMCtrace <- function(object,
         ylim <- c(0, max(max_den))
 
         graphics::plot(dens[[1]], xlab = 'Parameter estimate', ylim = ylim,
-             lty = 1, lwd = 1, main = paste0('Density - ', names[g_filt[j]]),
+             lty = 1, lwd = 1, main = paste0('Density - ', a_names[f_ind[j]]),
              col = grDevices::rgb(red= gg_cols[1,1], green= gg_cols[2,1], blue= gg_cols[3,1]))
 
         for (l in 2:NCOL(tmlt))
@@ -300,7 +338,7 @@ MCMCtrace <- function(object,
       }else{
         #density plot
         graphics::plot(stats::density(rbind(tmlt)), xlab = 'Parameter estimate',
-             lty = 1, lwd = 1, main = paste0('Density - ', names[g_filt[j]]))
+             lty = 1, lwd = 1, main = paste0('Density - ', a_names[f_ind[j]]))
       }
     }
   }
@@ -314,8 +352,7 @@ MCMCtrace <- function(object,
   {
     invisible(grDevices::dev.off())
     system(paste0('open ', paste0('"', file_out, '"')))
+  }else{
+    graphics::par(.pardefault)
   }
-
-  graphics::par(.pardefault)
-
 }
